@@ -193,15 +193,7 @@ build_rmds = function(files, knitting = is_knitting()) {
     }
 
     if (get_option('blogdown.widgetsID', TRUE)) x = clean_widget_html(x)
-    if (to_md) {
-      write_utf8(x, out)
-    } else {
-      prepend_yaml(f, out, x, callback = function(s) {
-        if (!getOption('blogdown.draft.output', FALSE)) return(s)
-        if (length(s) < 2 || length(grep('^draft: ', s)) > 0) return(s)
-        append(s, 'draft: true', 1)
-      })
-    }
+    write_utf8(x, out)
     msg_knit(f, FALSE)
   }
 }
